summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMasaya Tojo <masaya@tojo.tokyo>2020-11-09 02:56:59 +0900
committerMasaya Tojo <masaya@tojo.tokyo>2020-11-09 02:56:59 +0900
commit7a238e7df0c9c7c684b7f761f495b21aa088bd68 (patch)
tree299eb84b8706557655a6ea01d32ab37ec94d2789
parent51b6399599676a5c1a9c6cb27be88a1381f7af8a (diff)
wip10
-rw-r--r--Makefile.am12
-rw-r--r--README.org4
-rw-r--r--configure.ac4
-rw-r--r--guix.scm24
-rw-r--r--pre-inst-env.in10
-rw-r--r--vikalpa.scm (renamed from rabbit-prover.scm)16
-rw-r--r--vikalpa/ord.scm (renamed from rabbit-prover/ord.scm)16
-rw-r--r--vikalpa/primitive.scm (renamed from rabbit-prover/primitive.scm)12
-rw-r--r--vikalpa/syntax.scm (renamed from rabbit-prover/syntax.scm)12
9 files changed, 55 insertions, 55 deletions
diff --git a/Makefile.am b/Makefile.am
index 921ba1e..33ca8b7 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -1,20 +1,20 @@
-## Rabbit Prover --- Prove S-expression
+## Vikalpa --- Proof Assistant
## Copyright © 2020 Masaya Tojo <masaya@tojo.tokyo>
##
-## This file is part of Rabbit Prover.
+## This file is part of Vikalpa.
##
-## Rabbit Prover is free software; you can redistribute it and/or modify it
+## Vikalpa is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
-## Rabbit Prover is distributed in the hope that it will be useful, but
+## Vikalpa is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
-## along with Rabbit Prover. If not, see <http://www.gnu.org/licenses/>.
+## along with Vikalpa. If not, see <http://www.gnu.org/licenses/>.
GOBJECTS = $(SOURCES:%.scm=%.go)
@@ -42,7 +42,7 @@ godir=$(libdir)/guile/$(GUILE_EFFECTIVE_VERSION)/site-ccache
bin_SCRIPTS =
SOURCES = \
- rabbit-prover.scm
+ vikalpa.scm
TESTS =
diff --git a/README.org b/README.org
index 6b33a7f..96d66fb 100644
--- a/README.org
+++ b/README.org
@@ -1,3 +1,3 @@
-* rabbit-prover
+* vikalpa
-Rabbit Prover is Prove S-expression.
+Vikalpa is Proof Assistant.
diff --git a/configure.ac b/configure.ac
index fdfce62..6d8e522 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1,5 +1,5 @@
-AC_INIT([rabbit-prover], [0.0.0])
-AC_CONFIG_SRCDIR([rabbit-prover.scm])
+AC_INIT([vikalpa], [0.0.0])
+AC_CONFIG_SRCDIR([vikalpa.scm])
AC_CONFIG_AUX_DIR([build-aux])
AM_INIT_AUTOMAKE([-Wall -Werror foreign])
AM_SILENT_RULES([yes])
diff --git a/pre-inst-env.in b/pre-inst-env.in
index 42c7ec7..25ecd03 100644
--- a/pre-inst-env.in
+++ b/pre-inst-env.in
@@ -1,22 +1,22 @@
#!/bin/sh
-# Rabbit Prover --- Prove S-expression
+# Vikalpa --- Proof Assistant
# Copyright © 2020 Masaya Tojo <masaya@tojo.tokyo>
#
-# This file is part of Rabbit Prover.
+# This file is part of Vikalpa.
#
-# Rabbit Prover is free software; you can redistribute it and/or modify it
+# Vikalpa is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
-# Rabbit Prover is distributed in the hope that it will be useful, but WITHOUT
+# Vikalpa is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
# License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with Rabbit Prover. If not, see <http://www.gnu.org/licenses/>.
+# along with Vikalpa. If not, see <http://www.gnu.org/licenses/>.
abs_top_srcdir="`cd "@abs_top_srcdir@" > /dev/null; pwd`"
abs_top_builddir="`cd "@abs_top_builddir@" > /dev/null; pwd`"
diff --git a/guix.scm b/guix.scm
index 92731d5..694101d 100644
--- a/guix.scm
+++ b/guix.scm
@@ -1,20 +1,20 @@
-;;; Rabbit Prover --- Prove S-expression
+;;; Vikalpa --- Proof Assistant
;;; Copyright © 2020 Masaya Tojo <masaya@tojo.tokyo>
;;;
;;; This file is part of Rabbit Prover.
;;;
;;; Rabbit Prover is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or
;;; (at your option) any later version.
;;;
;;; Rabbit Prover is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
;;; General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
-;;; along with Rabbit Prover. If not, see <http://www.gnu.org/licenses/>.
+;;; along with Vikalpa. If not, see <http://www.gnu.org/licenses/>.
(use-modules (guix packages)
((guix licenses) #:prefix license:)
@@ -26,11 +26,11 @@
(gnu packages pkg-config)
(gnu packages texinfo))
-(define guile-rabbit-prover
+(define guile-vikalpa
(package
- (name "guile-rabbit-prover")
+ (name "guile-vikalpa")
(version "0.0.0")
- (source (string-append (getcwd) "/rabbit-prover-" version ".tar.gz"))
+ (source (string-append (getcwd) "/vikalpa-" version ".tar.gz"))
(build-system gnu-build-system)
(native-inputs
`(("autoconf" ,autoconf)
@@ -39,9 +39,9 @@
("texinfo" ,texinfo)))
(inputs
`(("guile" ,guile-3.0)))
- (synopsis "Prove S-expression")
- (description "Rabbit Prover is Prove S-expression.")
- (home-page "https://gitlab.com/tojoqk/rabbit-prover")
+ (synopsis "Proof Assistant")
+ (description "Vikalpa is Proof Assistant.")
+ (home-page "https://gitlab.com/tojoqk/vikalpa")
(license license:gpl3+)))
-guile-rabbit-prover
+guile-vikalpa
@@ -1,20 +1,20 @@
;;; Copyright © 2020 Masaya Tojo <masaya@tojo.tokyo>
;;;
-;;; This file is part of Rabbit Prover.
+;;; This file is part of Vikalpa.
;;;
@@ -1,20 +1,20 @@
;;;
-;;; Rabbit Prover is free software; you can redistribute it and/or modify it
+;;; Vikalpa is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or
@@ -1,20 +1,20 @@
;;; (at your option) any later version.
;;;
-;;; Rabbit Prover is distributed in the hope that it will be useful, but
+;;; Vikalpa is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
diff --git a/rabbit-prover.scm b/vikalpa.scm
index e83ea9a..5a51cfa 100644
--- a/rabbit-prover.scm
+++ b/vikalpa.scm
@@ -1,25 +1,25 @@
-;;; Rabbit Prover --- Prove S-expression
+;;; Vikalpa --- Prove S-expression
;;; Copyright © 2020 Masaya Tojo <masaya@tojo.tokyo>
;;;
;;; This file is part of Rabbit Prover.
;;;
;;; Rabbit Prover is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or
;;; (at your option) any later version.
;;;
;;; Rabbit Prover is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
;;; General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
-;;; along with Rabbit Prover. If not, see <http://www.gnu.org/licenses/>.
+;;; along with Vikalpa. If not, see <http://www.gnu.org/licenses/>.
-(define-module (rabbit-prover)
+(define-module (vikalpa)
#:export (rewrite)
- #:use-module (rabbit-prover syntax)
- #:use-module (rabbit-prover primitive)
+ #:use-module (vikalpa syntax)
+ #:use-module (vikalpa primitive)
#:use-module (ice-9 match)
#:use-module ((srfi srfi-1) #:select (every any member))
#:use-module (srfi srfi-8)
@@ -1,25 +1,25 @@
;;; Copyright © 2020 Masaya Tojo <masaya@tojo.tokyo>
;;;
-;;; This file is part of Rabbit Prover.
+;;; This file is part of Vikalpa.
;;;
@@ -1,25 +1,25 @@
;;;
-;;; Rabbit Prover is free software; you can redistribute it and/or modify it
+;;; Vikalpa is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or
@@ -1,25 +1,25 @@
;;; (at your option) any later version.
;;;
-;;; Rabbit Prover is distributed in the hope that it will be useful, but
+;;; Vikalpa is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
diff --git a/rabbit-prover/ord.scm b/vikalpa/ord.scm
index c752d36..9715979 100644
--- a/rabbit-prover/ord.scm
+++ b/vikalpa/ord.scm
@@ -1,22 +1,22 @@
-;;; Rabbit Prover --- Prove S-expression
+;;; Vikalpa --- Prove S-expression
;;; Copyright © 2020 Masaya Tojo <masaya@tojo.tokyo>
;;;
;;; This file is part of Rabbit Prover.
;;;
;;; Rabbit Prover is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or
;;; (at your option) any later version.
;;;
;;; Rabbit Prover is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
;;; General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
-;;; along with Rabbit Prover. If not, see <http://www.gnu.org/licenses/>.
+;;; along with Vikalpa. If not, see <http://www.gnu.org/licenses/>.
-(define-module (rabbit-prover ord)
+(define-module (vikalpa ord)
#:export (ord?
ord-fin?
ord-inf?
@@ -24,8 +24,8 @@
ord-first-coeff
ord-rest
ord<)
- #:use-module (rabbit-prover syntax)
- #:use-module (rabbit-prover primitive))
+ #:use-module (vikalpa syntax)
+ #:use-module (vikalpa primitive))
;;; ACL2's O-p
;; https://www.cs.utexas.edu/users/moore/acl2/manuals/current/manual/index-seo.php/ACL2____O-P?path=3574/6842/3819/225/243
@@ -1,22 +1,22 @@
;;; Copyright © 2020 Masaya Tojo <masaya@tojo.tokyo>
;;;
-;;; This file is part of Rabbit Prover.
+;;; This file is part of Vikalpa.
;;;
@@ -1,22 +1,22 @@
;;;
-;;; Rabbit Prover is free software; you can redistribute it and/or modify it
+;;; Vikalpa is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or
@@ -1,22 +1,22 @@
;;; (at your option) any later version.
;;;
-;;; Rabbit Prover is distributed in the hope that it will be useful, but
+;;; Vikalpa is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
diff --git a/rabbit-prover/primitive.scm b/vikalpa/primitive.scm
index e20406e..bcbced5 100644
--- a/rabbit-prover/primitive.scm
+++ b/vikalpa/primitive.scm
@@ -1,22 +1,22 @@
-;;; Rabbit Prover --- Prove S-expression
+;;; Vikalpa --- Proof Assistant
;;; Copyright © 2020 Masaya Tojo <masaya@tojo.tokyo>
;;;
;;; This file is part of Rabbit Prover.
;;;
;;; Rabbit Prover is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or
;;; (at your option) any later version.
;;;
;;; Rabbit Prover is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
;;; General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
-;;; along with Rabbit Prover. If not, see <http://www.gnu.org/licenses/>.
+;;; along with Vikalpa. If not, see <http://www.gnu.org/licenses/>.
-(define-module (rabbit-prover primitive)
+(define-module (vikalpa primitive)
#:export (natural?))
;; (natural? x) -> boolean?
@@ -1,22 +1,22 @@
;;; Copyright © 2020 Masaya Tojo <masaya@tojo.tokyo>
;;;
-;;; This file is part of Rabbit Prover.
+;;; This file is part of Vikalpa.
;;;
@@ -1,22 +1,22 @@
;;;
-;;; Rabbit Prover is free software; you can redistribute it and/or modify it
+;;; Vikalpa is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or
@@ -1,22 +1,22 @@
;;; (at your option) any later version.
;;;
-;;; Rabbit Prover is distributed in the hope that it will be useful, but
+;;; Vikalpa is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
diff --git a/rabbit-prover/syntax.scm b/vikalpa/syntax.scm
index 5087ea2..046c13a 100644
--- a/rabbit-prover/syntax.scm
+++ b/vikalpa/syntax.scm
@@ -1,22 +1,22 @@
-;;; Rabbit Prover --- Prove S-expression
+;;; Vikalpa --- Prove S-expression
;;; Copyright © 2020 Masaya Tojo <masaya@tojo.tokyo>
;;;
;;; This file is part of Rabbit Prover.
;;;
;;; Rabbit Prover is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or
;;; (at your option) any later version.
;;;
;;; Rabbit Prover is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
;;; General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
-;;; along with Rabbit Prover. If not, see <http://www.gnu.org/licenses/>.
+;;; along with Vikalpa. If not, see <http://www.gnu.org/licenses/>.
-(define-module (rabbit-prover syntax)
+(define-module (vikalpa syntax)
#:export (define/guard))
(define-syntax-rule (define/guard (name (var pred?) ...) b b* ...)
@@ -1,22 +1,22 @@
;;; Copyright © 2020 Masaya Tojo <masaya@tojo.tokyo>
;;;
-;;; This file is part of Rabbit Prover.
+;;; This file is part of Vikalpa.
;;;
@@ -1,22 +1,22 @@
;;;
-;;; Rabbit Prover is free software; you can redistribute it and/or modify it
+;;; Vikalpa is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or
@@ -1,22 +1,22 @@
;;; (at your option) any later version.
;;;
-;;; Rabbit Prover is distributed in the hope that it will be useful, but
+;;; Vikalpa is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU